# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'InstanceEndpoints',
    'InstanceEndpointsOverlay',
    'InstanceEndpointsPublic',
    'InstanceResourceTag',
    'InstanceResourceTagTagKv',
    'InstanceResources',
    'InstanceResourcesStorage',
    'InstanceTag',
    'GetInstanceEndpointsResult',
    'GetInstanceEndpointsOverlayResult',
    'GetInstanceEndpointsPublicResult',
    'GetInstanceResourceTagResult',
    'GetInstanceResourceTagTagKvResult',
    'GetInstanceResourcesResult',
    'GetInstanceResourcesStorageResult',
    'GetInstanceTagResult',
]

@pulumi.output_type
class InstanceEndpoints(dict):
    def __init__(__self__, *,
                 overlay: Optional['outputs.InstanceEndpointsOverlay'] = None,
                 public: Optional['outputs.InstanceEndpointsPublic'] = None):
        """
        :param 'InstanceEndpointsOverlayArgs' overlay: 实例私网访问接入点响应数据。
        :param 'InstanceEndpointsPublicArgs' public: 实例公网访问接入点响应数据。
        """
        if overlay is not None:
            pulumi.set(__self__, "overlay", overlay)
        if public is not None:
            pulumi.set(__self__, "public", public)

    @property
    @pulumi.getter
    def overlay(self) -> Optional['outputs.InstanceEndpointsOverlay']:
        """
        实例私网访问接入点响应数据。
        """
        return pulumi.get(self, "overlay")

    @property
    @pulumi.getter
    def public(self) -> Optional['outputs.InstanceEndpointsPublic']:
        """
        实例公网访问接入点响应数据。
        """
        return pulumi.get(self, "public")


@pulumi.output_type
class InstanceEndpointsOverlay(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "eipId":
            suggest = "eip_id"
        elif key == "plainPort":
            suggest = "plain_port"
        elif key == "saslPort":
            suggest = "sasl_port"
        elif key == "sslPort":
            suggest = "ssl_port"
        elif key == "vpcIds":
            suggest = "vpc_ids"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceEndpointsOverlay. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceEndpointsOverlay.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceEndpointsOverlay.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 address: Optional[builtins.str] = None,
                 eip_id: Optional[builtins.str] = None,
                 plain: Optional[builtins.str] = None,
                 plain_port: Optional[builtins.int] = None,
                 sasl: Optional[builtins.str] = None,
                 sasl_port: Optional[builtins.int] = None,
                 ssl: Optional[builtins.str] = None,
                 ssl_port: Optional[builtins.int] = None,
                 status: Optional[builtins.str] = None,
                 vpc_ids: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.str address: 域名映射地址。
        :param builtins.str eip_id: 实例绑定的EIP的ID。
        :param builtins.str plain: 私网Plain接入点。
        :param builtins.int plain_port: 普通接入点端口。
        :param builtins.str sasl: 私网SASL认证接入点。
        :param builtins.int sasl_port: 认证接入点端口。
        :param builtins.str ssl: 加密接入点。
        :param builtins.int ssl_port: 加密接入点端口。
        :param builtins.str status: 接入点状态。
        :param Sequence[builtins.str] vpc_ids: 售卖区网络关联的VPC ID列表。
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if plain is not None:
            pulumi.set(__self__, "plain", plain)
        if plain_port is not None:
            pulumi.set(__self__, "plain_port", plain_port)
        if sasl is not None:
            pulumi.set(__self__, "sasl", sasl)
        if sasl_port is not None:
            pulumi.set(__self__, "sasl_port", sasl_port)
        if ssl is not None:
            pulumi.set(__self__, "ssl", ssl)
        if ssl_port is not None:
            pulumi.set(__self__, "ssl_port", ssl_port)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_ids is not None:
            pulumi.set(__self__, "vpc_ids", vpc_ids)

    @property
    @pulumi.getter
    def address(self) -> Optional[builtins.str]:
        """
        域名映射地址。
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[builtins.str]:
        """
        实例绑定的EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def plain(self) -> Optional[builtins.str]:
        """
        私网Plain接入点。
        """
        return pulumi.get(self, "plain")

    @property
    @pulumi.getter(name="plainPort")
    def plain_port(self) -> Optional[builtins.int]:
        """
        普通接入点端口。
        """
        return pulumi.get(self, "plain_port")

    @property
    @pulumi.getter
    def sasl(self) -> Optional[builtins.str]:
        """
        私网SASL认证接入点。
        """
        return pulumi.get(self, "sasl")

    @property
    @pulumi.getter(name="saslPort")
    def sasl_port(self) -> Optional[builtins.int]:
        """
        认证接入点端口。
        """
        return pulumi.get(self, "sasl_port")

    @property
    @pulumi.getter
    def ssl(self) -> Optional[builtins.str]:
        """
        加密接入点。
        """
        return pulumi.get(self, "ssl")

    @property
    @pulumi.getter(name="sslPort")
    def ssl_port(self) -> Optional[builtins.int]:
        """
        加密接入点端口。
        """
        return pulumi.get(self, "ssl_port")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        """
        接入点状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcIds")
    def vpc_ids(self) -> Optional[Sequence[builtins.str]]:
        """
        售卖区网络关联的VPC ID列表。
        """
        return pulumi.get(self, "vpc_ids")


@pulumi.output_type
class InstanceEndpointsPublic(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "eipId":
            suggest = "eip_id"
        elif key == "plainPort":
            suggest = "plain_port"
        elif key == "saslPort":
            suggest = "sasl_port"
        elif key == "sslPort":
            suggest = "ssl_port"
        elif key == "vpcIds":
            suggest = "vpc_ids"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceEndpointsPublic. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceEndpointsPublic.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceEndpointsPublic.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 address: Optional[builtins.str] = None,
                 eip_id: Optional[builtins.str] = None,
                 plain: Optional[builtins.str] = None,
                 plain_port: Optional[builtins.int] = None,
                 sasl: Optional[builtins.str] = None,
                 sasl_port: Optional[builtins.int] = None,
                 ssl: Optional[builtins.str] = None,
                 ssl_port: Optional[builtins.int] = None,
                 status: Optional[builtins.str] = None,
                 vpc_ids: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.str address: 域名映射地址。
        :param builtins.str eip_id: 实例绑定的EIP的ID。
        :param builtins.str plain: 私网Plain接入点。
        :param builtins.int plain_port: 普通接入点端口。
        :param builtins.str sasl: 私网SASL认证接入点。
        :param builtins.int sasl_port: 认证接入点端口。
        :param builtins.str ssl: 加密接入点。
        :param builtins.int ssl_port: 加密接入点端口。
        :param builtins.str status: 接入点状态。
        :param Sequence[builtins.str] vpc_ids: 售卖区网络关联的VPC ID列表。
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if plain is not None:
            pulumi.set(__self__, "plain", plain)
        if plain_port is not None:
            pulumi.set(__self__, "plain_port", plain_port)
        if sasl is not None:
            pulumi.set(__self__, "sasl", sasl)
        if sasl_port is not None:
            pulumi.set(__self__, "sasl_port", sasl_port)
        if ssl is not None:
            pulumi.set(__self__, "ssl", ssl)
        if ssl_port is not None:
            pulumi.set(__self__, "ssl_port", ssl_port)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_ids is not None:
            pulumi.set(__self__, "vpc_ids", vpc_ids)

    @property
    @pulumi.getter
    def address(self) -> Optional[builtins.str]:
        """
        域名映射地址。
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[builtins.str]:
        """
        实例绑定的EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def plain(self) -> Optional[builtins.str]:
        """
        私网Plain接入点。
        """
        return pulumi.get(self, "plain")

    @property
    @pulumi.getter(name="plainPort")
    def plain_port(self) -> Optional[builtins.int]:
        """
        普通接入点端口。
        """
        return pulumi.get(self, "plain_port")

    @property
    @pulumi.getter
    def sasl(self) -> Optional[builtins.str]:
        """
        私网SASL认证接入点。
        """
        return pulumi.get(self, "sasl")

    @property
    @pulumi.getter(name="saslPort")
    def sasl_port(self) -> Optional[builtins.int]:
        """
        认证接入点端口。
        """
        return pulumi.get(self, "sasl_port")

    @property
    @pulumi.getter
    def ssl(self) -> Optional[builtins.str]:
        """
        加密接入点。
        """
        return pulumi.get(self, "ssl")

    @property
    @pulumi.getter(name="sslPort")
    def ssl_port(self) -> Optional[builtins.int]:
        """
        加密接入点端口。
        """
        return pulumi.get(self, "ssl_port")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        """
        接入点状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcIds")
    def vpc_ids(self) -> Optional[Sequence[builtins.str]]:
        """
        售卖区网络关联的VPC ID列表。
        """
        return pulumi.get(self, "vpc_ids")


@pulumi.output_type
class InstanceResourceTag(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "tagKvs":
            suggest = "tag_kvs"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceResourceTag. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceResourceTag.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceResourceTag.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 tag_kvs: Optional[Sequence['outputs.InstanceResourceTagTagKv']] = None,
                 type: Optional[builtins.str] = None):
        """
        :param builtins.str type: 标签类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        if tag_kvs is not None:
            pulumi.set(__self__, "tag_kvs", tag_kvs)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="tagKvs")
    def tag_kvs(self) -> Optional[Sequence['outputs.InstanceResourceTagTagKv']]:
        return pulumi.get(self, "tag_kvs")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        标签类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class InstanceResourceTagTagKv(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 type: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str type: 实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class InstanceResources(dict):
    def __init__(__self__, *,
                 storage: Optional['outputs.InstanceResourcesStorage'] = None):
        """
        :param 'InstanceResourcesStorageArgs' storage: 资源统计响应数据。
        """
        if storage is not None:
            pulumi.set(__self__, "storage", storage)

    @property
    @pulumi.getter
    def storage(self) -> Optional['outputs.InstanceResourcesStorage']:
        """
        资源统计响应数据。
        """
        return pulumi.get(self, "storage")


@pulumi.output_type
class InstanceResourcesStorage(dict):
    def __init__(__self__, *,
                 size: Optional[builtins.int] = None,
                 unit: Optional[builtins.str] = None):
        """
        :param builtins.int size: 资源大小。
        :param builtins.str unit: 资源单位。
        """
        if size is not None:
            pulumi.set(__self__, "size", size)
        if unit is not None:
            pulumi.set(__self__, "unit", unit)

    @property
    @pulumi.getter
    def size(self) -> Optional[builtins.int]:
        """
        资源大小。
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def unit(self) -> Optional[builtins.str]:
        """
        资源单位。
        """
        return pulumi.get(self, "unit")


@pulumi.output_type
class InstanceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 type: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str type: 实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInstanceEndpointsResult(dict):
    def __init__(__self__, *,
                 overlay: 'outputs.GetInstanceEndpointsOverlayResult',
                 public: 'outputs.GetInstanceEndpointsPublicResult'):
        """
        :param 'GetInstanceEndpointsOverlayArgs' overlay: 实例私网访问接入点响应数据。
        :param 'GetInstanceEndpointsPublicArgs' public: 实例公网访问接入点响应数据。
        """
        pulumi.set(__self__, "overlay", overlay)
        pulumi.set(__self__, "public", public)

    @property
    @pulumi.getter
    def overlay(self) -> 'outputs.GetInstanceEndpointsOverlayResult':
        """
        实例私网访问接入点响应数据。
        """
        return pulumi.get(self, "overlay")

    @property
    @pulumi.getter
    def public(self) -> 'outputs.GetInstanceEndpointsPublicResult':
        """
        实例公网访问接入点响应数据。
        """
        return pulumi.get(self, "public")


@pulumi.output_type
class GetInstanceEndpointsOverlayResult(dict):
    def __init__(__self__, *,
                 address: builtins.str,
                 eip_id: builtins.str,
                 plain: builtins.str,
                 plain_port: builtins.int,
                 sasl: builtins.str,
                 sasl_port: builtins.int,
                 ssl: builtins.str,
                 ssl_port: builtins.int,
                 status: builtins.str,
                 vpc_ids: Sequence[builtins.str]):
        """
        :param builtins.str address: 域名映射地址。
        :param builtins.str eip_id: 实例绑定的EIP的ID。
        :param builtins.str plain: 私网Plain接入点。
        :param builtins.int plain_port: 普通接入点端口。
        :param builtins.str sasl: 私网SASL认证接入点。
        :param builtins.int sasl_port: 认证接入点端口。
        :param builtins.str ssl: 加密接入点。
        :param builtins.int ssl_port: 加密接入点端口。
        :param builtins.str status: 接入点状态。
        :param Sequence[builtins.str] vpc_ids: 售卖区网络关联的VPC ID列表。
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "eip_id", eip_id)
        pulumi.set(__self__, "plain", plain)
        pulumi.set(__self__, "plain_port", plain_port)
        pulumi.set(__self__, "sasl", sasl)
        pulumi.set(__self__, "sasl_port", sasl_port)
        pulumi.set(__self__, "ssl", ssl)
        pulumi.set(__self__, "ssl_port", ssl_port)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "vpc_ids", vpc_ids)

    @property
    @pulumi.getter
    def address(self) -> builtins.str:
        """
        域名映射地址。
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> builtins.str:
        """
        实例绑定的EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def plain(self) -> builtins.str:
        """
        私网Plain接入点。
        """
        return pulumi.get(self, "plain")

    @property
    @pulumi.getter(name="plainPort")
    def plain_port(self) -> builtins.int:
        """
        普通接入点端口。
        """
        return pulumi.get(self, "plain_port")

    @property
    @pulumi.getter
    def sasl(self) -> builtins.str:
        """
        私网SASL认证接入点。
        """
        return pulumi.get(self, "sasl")

    @property
    @pulumi.getter(name="saslPort")
    def sasl_port(self) -> builtins.int:
        """
        认证接入点端口。
        """
        return pulumi.get(self, "sasl_port")

    @property
    @pulumi.getter
    def ssl(self) -> builtins.str:
        """
        加密接入点。
        """
        return pulumi.get(self, "ssl")

    @property
    @pulumi.getter(name="sslPort")
    def ssl_port(self) -> builtins.int:
        """
        加密接入点端口。
        """
        return pulumi.get(self, "ssl_port")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        接入点状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcIds")
    def vpc_ids(self) -> Sequence[builtins.str]:
        """
        售卖区网络关联的VPC ID列表。
        """
        return pulumi.get(self, "vpc_ids")


@pulumi.output_type
class GetInstanceEndpointsPublicResult(dict):
    def __init__(__self__, *,
                 address: builtins.str,
                 eip_id: builtins.str,
                 plain: builtins.str,
                 plain_port: builtins.int,
                 sasl: builtins.str,
                 sasl_port: builtins.int,
                 ssl: builtins.str,
                 ssl_port: builtins.int,
                 status: builtins.str,
                 vpc_ids: Sequence[builtins.str]):
        """
        :param builtins.str address: 域名映射地址。
        :param builtins.str eip_id: 实例绑定的EIP的ID。
        :param builtins.str plain: 私网Plain接入点。
        :param builtins.int plain_port: 普通接入点端口。
        :param builtins.str sasl: 私网SASL认证接入点。
        :param builtins.int sasl_port: 认证接入点端口。
        :param builtins.str ssl: 加密接入点。
        :param builtins.int ssl_port: 加密接入点端口。
        :param builtins.str status: 接入点状态。
        :param Sequence[builtins.str] vpc_ids: 售卖区网络关联的VPC ID列表。
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "eip_id", eip_id)
        pulumi.set(__self__, "plain", plain)
        pulumi.set(__self__, "plain_port", plain_port)
        pulumi.set(__self__, "sasl", sasl)
        pulumi.set(__self__, "sasl_port", sasl_port)
        pulumi.set(__self__, "ssl", ssl)
        pulumi.set(__self__, "ssl_port", ssl_port)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "vpc_ids", vpc_ids)

    @property
    @pulumi.getter
    def address(self) -> builtins.str:
        """
        域名映射地址。
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> builtins.str:
        """
        实例绑定的EIP的ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter
    def plain(self) -> builtins.str:
        """
        私网Plain接入点。
        """
        return pulumi.get(self, "plain")

    @property
    @pulumi.getter(name="plainPort")
    def plain_port(self) -> builtins.int:
        """
        普通接入点端口。
        """
        return pulumi.get(self, "plain_port")

    @property
    @pulumi.getter
    def sasl(self) -> builtins.str:
        """
        私网SASL认证接入点。
        """
        return pulumi.get(self, "sasl")

    @property
    @pulumi.getter(name="saslPort")
    def sasl_port(self) -> builtins.int:
        """
        认证接入点端口。
        """
        return pulumi.get(self, "sasl_port")

    @property
    @pulumi.getter
    def ssl(self) -> builtins.str:
        """
        加密接入点。
        """
        return pulumi.get(self, "ssl")

    @property
    @pulumi.getter(name="sslPort")
    def ssl_port(self) -> builtins.int:
        """
        加密接入点端口。
        """
        return pulumi.get(self, "ssl_port")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        接入点状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcIds")
    def vpc_ids(self) -> Sequence[builtins.str]:
        """
        售卖区网络关联的VPC ID列表。
        """
        return pulumi.get(self, "vpc_ids")


@pulumi.output_type
class GetInstanceResourceTagResult(dict):
    def __init__(__self__, *,
                 tag_kvs: Sequence['outputs.GetInstanceResourceTagTagKvResult'],
                 type: builtins.str):
        """
        :param Sequence['GetInstanceResourceTagTagKvArgs'] tag_kvs: 标签键值对。
        :param builtins.str type: 标签类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        pulumi.set(__self__, "tag_kvs", tag_kvs)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="tagKvs")
    def tag_kvs(self) -> Sequence['outputs.GetInstanceResourceTagTagKvResult']:
        """
        标签键值对。
        """
        return pulumi.get(self, "tag_kvs")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        标签类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetInstanceResourceTagTagKvResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 type: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str type: 实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInstanceResourcesResult(dict):
    def __init__(__self__, *,
                 storage: 'outputs.GetInstanceResourcesStorageResult'):
        """
        :param 'GetInstanceResourcesStorageArgs' storage: 资源统计响应数据。
        """
        pulumi.set(__self__, "storage", storage)

    @property
    @pulumi.getter
    def storage(self) -> 'outputs.GetInstanceResourcesStorageResult':
        """
        资源统计响应数据。
        """
        return pulumi.get(self, "storage")


@pulumi.output_type
class GetInstanceResourcesStorageResult(dict):
    def __init__(__self__, *,
                 size: builtins.int,
                 unit: builtins.str):
        """
        :param builtins.int size: 资源大小。
        :param builtins.str unit: 资源单位。
        """
        pulumi.set(__self__, "size", size)
        pulumi.set(__self__, "unit", unit)

    @property
    @pulumi.getter
    def size(self) -> builtins.int:
        """
        资源大小。
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def unit(self) -> builtins.str:
        """
        资源单位。
        """
        return pulumi.get(self, "unit")


@pulumi.output_type
class GetInstanceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 type: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str type: 实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        实例标签的类型，取值如下：CUSTOM：自定义设置标签。SYSTEM：系统标签。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ShareConfigAllowIpAccessRuleArgs',
    'ShareConfigAllowIpAccessRuleArgsDict',
    'ShareConfigAllowRefererAccessRuleArgs',
    'ShareConfigAllowRefererAccessRuleArgsDict',
    'ShareConfigAllowRefererAccessRuleCommonTypeArgs',
    'ShareConfigAllowRefererAccessRuleCommonTypeArgsDict',
    'ShareConfigCommonMatchsArgs',
    'ShareConfigCommonMatchsArgsDict',
    'ShareConfigCommonMatchsCommonTypeArgs',
    'ShareConfigCommonMatchsCommonTypeArgsDict',
    'ShareConfigDenyIpAccessRuleArgs',
    'ShareConfigDenyIpAccessRuleArgsDict',
    'ShareConfigDenyRefererAccessRuleArgs',
    'ShareConfigDenyRefererAccessRuleArgsDict',
    'ShareConfigDenyRefererAccessRuleCommonTypeArgs',
    'ShareConfigDenyRefererAccessRuleCommonTypeArgsDict',
]

MYPY = False

if not MYPY:
    class ShareConfigAllowIpAccessRuleArgsDict(TypedDict):
        rules: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
elif False:
    ShareConfigAllowIpAccessRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ShareConfigAllowIpAccessRuleArgs:
    def __init__(__self__, *,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] rules: 表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "rules", value)


if not MYPY:
    class ShareConfigAllowRefererAccessRuleArgsDict(TypedDict):
        allow_empty: NotRequired[pulumi.Input[builtins.bool]]
        """
        表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        """
        common_type: NotRequired[pulumi.Input['ShareConfigAllowRefererAccessRuleCommonTypeArgsDict']]
        """
        表示该通用列表的内容。
        """
elif False:
    ShareConfigAllowRefererAccessRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ShareConfigAllowRefererAccessRuleArgs:
    def __init__(__self__, *,
                 allow_empty: Optional[pulumi.Input[builtins.bool]] = None,
                 common_type: Optional[pulumi.Input['ShareConfigAllowRefererAccessRuleCommonTypeArgs']] = None):
        """
        :param pulumi.Input[builtins.bool] allow_empty: 表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        :param pulumi.Input['ShareConfigAllowRefererAccessRuleCommonTypeArgs'] common_type: 表示该通用列表的内容。
        """
        if allow_empty is not None:
            pulumi.set(__self__, "allow_empty", allow_empty)
        if common_type is not None:
            pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        """
        return pulumi.get(self, "allow_empty")

    @allow_empty.setter
    def allow_empty(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_empty", value)

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> Optional[pulumi.Input['ShareConfigAllowRefererAccessRuleCommonTypeArgs']]:
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")

    @common_type.setter
    def common_type(self, value: Optional[pulumi.Input['ShareConfigAllowRefererAccessRuleCommonTypeArgs']]):
        pulumi.set(self, "common_type", value)


if not MYPY:
    class ShareConfigAllowRefererAccessRuleCommonTypeArgsDict(TypedDict):
        ignore_case: NotRequired[pulumi.Input[builtins.bool]]
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        rules: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
elif False:
    ShareConfigAllowRefererAccessRuleCommonTypeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ShareConfigAllowRefererAccessRuleCommonTypeArgs:
    def __init__(__self__, *,
                 ignore_case: Optional[pulumi.Input[builtins.bool]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[builtins.bool] ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        if ignore_case is not None:
            pulumi.set(__self__, "ignore_case", ignore_case)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @ignore_case.setter
    def ignore_case(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_case", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "rules", value)


if not MYPY:
    class ShareConfigCommonMatchsArgsDict(TypedDict):
        common_type: NotRequired[pulumi.Input['ShareConfigCommonMatchsCommonTypeArgsDict']]
        """
        表示该通用列表的内容。
        """
elif False:
    ShareConfigCommonMatchsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ShareConfigCommonMatchsArgs:
    def __init__(__self__, *,
                 common_type: Optional[pulumi.Input['ShareConfigCommonMatchsCommonTypeArgs']] = None):
        """
        :param pulumi.Input['ShareConfigCommonMatchsCommonTypeArgs'] common_type: 表示该通用列表的内容。
        """
        if common_type is not None:
            pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> Optional[pulumi.Input['ShareConfigCommonMatchsCommonTypeArgs']]:
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")

    @common_type.setter
    def common_type(self, value: Optional[pulumi.Input['ShareConfigCommonMatchsCommonTypeArgs']]):
        pulumi.set(self, "common_type", value)


if not MYPY:
    class ShareConfigCommonMatchsCommonTypeArgsDict(TypedDict):
        ignore_case: NotRequired[pulumi.Input[builtins.bool]]
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        rules: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
elif False:
    ShareConfigCommonMatchsCommonTypeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ShareConfigCommonMatchsCommonTypeArgs:
    def __init__(__self__, *,
                 ignore_case: Optional[pulumi.Input[builtins.bool]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[builtins.bool] ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        if ignore_case is not None:
            pulumi.set(__self__, "ignore_case", ignore_case)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @ignore_case.setter
    def ignore_case(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_case", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "rules", value)


if not MYPY:
    class ShareConfigDenyIpAccessRuleArgsDict(TypedDict):
        rules: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
elif False:
    ShareConfigDenyIpAccessRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ShareConfigDenyIpAccessRuleArgs:
    def __init__(__self__, *,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] rules: 表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "rules", value)


if not MYPY:
    class ShareConfigDenyRefererAccessRuleArgsDict(TypedDict):
        allow_empty: NotRequired[pulumi.Input[builtins.bool]]
        """
        表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        """
        common_type: NotRequired[pulumi.Input['ShareConfigDenyRefererAccessRuleCommonTypeArgsDict']]
        """
        表示该通用列表的内容。
        """
elif False:
    ShareConfigDenyRefererAccessRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ShareConfigDenyRefererAccessRuleArgs:
    def __init__(__self__, *,
                 allow_empty: Optional[pulumi.Input[builtins.bool]] = None,
                 common_type: Optional[pulumi.Input['ShareConfigDenyRefererAccessRuleCommonTypeArgs']] = None):
        """
        :param pulumi.Input[builtins.bool] allow_empty: 表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        :param pulumi.Input['ShareConfigDenyRefererAccessRuleCommonTypeArgs'] common_type: 表示该通用列表的内容。
        """
        if allow_empty is not None:
            pulumi.set(__self__, "allow_empty", allow_empty)
        if common_type is not None:
            pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        """
        return pulumi.get(self, "allow_empty")

    @allow_empty.setter
    def allow_empty(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_empty", value)

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> Optional[pulumi.Input['ShareConfigDenyRefererAccessRuleCommonTypeArgs']]:
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")

    @common_type.setter
    def common_type(self, value: Optional[pulumi.Input['ShareConfigDenyRefererAccessRuleCommonTypeArgs']]):
        pulumi.set(self, "common_type", value)


if not MYPY:
    class ShareConfigDenyRefererAccessRuleCommonTypeArgsDict(TypedDict):
        ignore_case: NotRequired[pulumi.Input[builtins.bool]]
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        rules: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
elif False:
    ShareConfigDenyRefererAccessRuleCommonTypeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ShareConfigDenyRefererAccessRuleCommonTypeArgs:
    def __init__(__self__, *,
                 ignore_case: Optional[pulumi.Input[builtins.bool]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[builtins.bool] ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        if ignore_case is not None:
            pulumi.set(__self__, "ignore_case", ignore_case)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @ignore_case.setter
    def ignore_case(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_case", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "rules", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RepositoryArgs', 'Repository']

@pulumi.input_type
class RepositoryArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str],
                 namespace: pulumi.Input[builtins.str],
                 registry: pulumi.Input[builtins.str],
                 access_level: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Repository resource.
        :param pulumi.Input[builtins.str] name: OCI 制品仓库名称。同一个命名空间下，名称必须唯一。支持小写英文、数字、分隔符（分隔符可输入一个.或/、一个或多个-、一个或两个_，且分隔符不能出现在首位或末位，不能连续出现），长度限制为 1～128 个字符。
        :param pulumi.Input[builtins.str] namespace: 目标命名空间名称。在 镜像仓库控制台 目标实例的 命名空间 页面，获取命名空间名称。
        :param pulumi.Input[builtins.str] registry: 指定命名空间所属的镜像仓库实例名称。在 镜像仓库控制台 的 实例列表 页面，获取实例名称。
        :param pulumi.Input[builtins.str] access_level: 访问等级，取值如下：Private：私有类型 OCI 制品仓库，只能被有权限的用户访问。Public：公有类型 OCI 制品仓库，可以被所有用户访问。单次可填写一个或多个访问等级。
        :param pulumi.Input[builtins.str] description: 镜像仓库描述，描述长度为 0~300 个 UTF-8 字符。
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "registry", registry)
        if access_level is not None:
            pulumi.set(__self__, "access_level", access_level)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        OCI 制品仓库名称。同一个命名空间下，名称必须唯一。支持小写英文、数字、分隔符（分隔符可输入一个.或/、一个或多个-、一个或两个_，且分隔符不能出现在首位或末位，不能连续出现），长度限制为 1～128 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[builtins.str]:
        """
        目标命名空间名称。在 镜像仓库控制台 目标实例的 命名空间 页面，获取命名空间名称。
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def registry(self) -> pulumi.Input[builtins.str]:
        """
        指定命名空间所属的镜像仓库实例名称。在 镜像仓库控制台 的 实例列表 页面，获取实例名称。
        """
        return pulumi.get(self, "registry")

    @registry.setter
    def registry(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "registry", value)

    @property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问等级，取值如下：Private：私有类型 OCI 制品仓库，只能被有权限的用户访问。Public：公有类型 OCI 制品仓库，可以被所有用户访问。单次可填写一个或多个访问等级。
        """
        return pulumi.get(self, "access_level")

    @access_level.setter
    def access_level(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_level", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像仓库描述，描述长度为 0~300 个 UTF-8 字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _RepositoryState:
    def __init__(__self__, *,
                 access_level: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 registry: Optional[pulumi.Input[builtins.str]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Repository resources.
        :param pulumi.Input[builtins.str] access_level: 访问等级，取值如下：Private：私有类型 OCI 制品仓库，只能被有权限的用户访问。Public：公有类型 OCI 制品仓库，可以被所有用户访问。单次可填写一个或多个访问等级。
        :param pulumi.Input[builtins.str] create_time: 创建 OCI 制品仓库的时间。RFC3339 格式的 UTC+0 时间。
        :param pulumi.Input[builtins.str] description: 镜像仓库描述，描述长度为 0~300 个 UTF-8 字符。
        :param pulumi.Input[builtins.str] name: OCI 制品仓库名称。同一个命名空间下，名称必须唯一。支持小写英文、数字、分隔符（分隔符可输入一个.或/、一个或多个-、一个或两个_，且分隔符不能出现在首位或末位，不能连续出现），长度限制为 1～128 个字符。
        :param pulumi.Input[builtins.str] namespace: 目标命名空间名称。在 镜像仓库控制台 目标实例的 命名空间 页面，获取命名空间名称。
        :param pulumi.Input[builtins.str] registry: 指定命名空间所属的镜像仓库实例名称。在 镜像仓库控制台 的 实例列表 页面，获取实例名称。
        :param pulumi.Input[builtins.str] update_time: 最近一次更新 OCI 制品仓库的时间。RFC3339 格式的 UTC+0 时间。
        """
        if access_level is not None:
            pulumi.set(__self__, "access_level", access_level)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if registry is not None:
            pulumi.set(__self__, "registry", registry)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问等级，取值如下：Private：私有类型 OCI 制品仓库，只能被有权限的用户访问。Public：公有类型 OCI 制品仓库，可以被所有用户访问。单次可填写一个或多个访问等级。
        """
        return pulumi.get(self, "access_level")

    @access_level.setter
    def access_level(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_level", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建 OCI 制品仓库的时间。RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像仓库描述，描述长度为 0~300 个 UTF-8 字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OCI 制品仓库名称。同一个命名空间下，名称必须唯一。支持小写英文、数字、分隔符（分隔符可输入一个.或/、一个或多个-、一个或两个_，且分隔符不能出现在首位或末位，不能连续出现），长度限制为 1～128 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        目标命名空间名称。在 镜像仓库控制台 目标实例的 命名空间 页面，获取命名空间名称。
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def registry(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定命名空间所属的镜像仓库实例名称。在 镜像仓库控制台 的 实例列表 页面，获取实例名称。
        """
        return pulumi.get(self, "registry")

    @registry.setter
    def registry(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "registry", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        最近一次更新 OCI 制品仓库的时间。RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.type_token("bytepluscc:cr/repository:Repository")
class Repository(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_level: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 registry: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        OCI 制品仓库用于存储容器镜像或 Helm Chart 等，符合开源容器标准的 OCI（Open Container Initiative） 制品。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        repository_demo = bytepluscc.cr.Repository("RepositoryDemo",
            registry="test",
            namespace="default",
            name="RepositoryDemo",
            description="RepositoryDemo description",
            access_level="Public")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:cr/repository:Repository example "registry|namespace|name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_level: 访问等级，取值如下：Private：私有类型 OCI 制品仓库，只能被有权限的用户访问。Public：公有类型 OCI 制品仓库，可以被所有用户访问。单次可填写一个或多个访问等级。
        :param pulumi.Input[builtins.str] description: 镜像仓库描述，描述长度为 0~300 个 UTF-8 字符。
        :param pulumi.Input[builtins.str] name: OCI 制品仓库名称。同一个命名空间下，名称必须唯一。支持小写英文、数字、分隔符（分隔符可输入一个.或/、一个或多个-、一个或两个_，且分隔符不能出现在首位或末位，不能连续出现），长度限制为 1～128 个字符。
        :param pulumi.Input[builtins.str] namespace: 目标命名空间名称。在 镜像仓库控制台 目标实例的 命名空间 页面，获取命名空间名称。
        :param pulumi.Input[builtins.str] registry: 指定命名空间所属的镜像仓库实例名称。在 镜像仓库控制台 的 实例列表 页面，获取实例名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepositoryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        OCI 制品仓库用于存储容器镜像或 Helm Chart 等，符合开源容器标准的 OCI（Open Container Initiative） 制品。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        repository_demo = bytepluscc.cr.Repository("RepositoryDemo",
            registry="test",
            namespace="default",
            name="RepositoryDemo",
            description="RepositoryDemo description",
            access_level="Public")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:cr/repository:Repository example "registry|namespace|name"
        ```

        :param str resource_name: The name of the resource.
        :param RepositoryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepositoryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_level: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 registry: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepositoryArgs.__new__(RepositoryArgs)

            __props__.__dict__["access_level"] = access_level
            __props__.__dict__["description"] = description
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            if namespace is None and not opts.urn:
                raise TypeError("Missing required property 'namespace'")
            __props__.__dict__["namespace"] = namespace
            if registry is None and not opts.urn:
                raise TypeError("Missing required property 'registry'")
            __props__.__dict__["registry"] = registry
            __props__.__dict__["create_time"] = None
            __props__.__dict__["update_time"] = None
        super(Repository, __self__).__init__(
            'bytepluscc:cr/repository:Repository',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_level: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            namespace: Optional[pulumi.Input[builtins.str]] = None,
            registry: Optional[pulumi.Input[builtins.str]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None) -> 'Repository':
        """
        Get an existing Repository resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_level: 访问等级，取值如下：Private：私有类型 OCI 制品仓库，只能被有权限的用户访问。Public：公有类型 OCI 制品仓库，可以被所有用户访问。单次可填写一个或多个访问等级。
        :param pulumi.Input[builtins.str] create_time: 创建 OCI 制品仓库的时间。RFC3339 格式的 UTC+0 时间。
        :param pulumi.Input[builtins.str] description: 镜像仓库描述，描述长度为 0~300 个 UTF-8 字符。
        :param pulumi.Input[builtins.str] name: OCI 制品仓库名称。同一个命名空间下，名称必须唯一。支持小写英文、数字、分隔符（分隔符可输入一个.或/、一个或多个-、一个或两个_，且分隔符不能出现在首位或末位，不能连续出现），长度限制为 1～128 个字符。
        :param pulumi.Input[builtins.str] namespace: 目标命名空间名称。在 镜像仓库控制台 目标实例的 命名空间 页面，获取命名空间名称。
        :param pulumi.Input[builtins.str] registry: 指定命名空间所属的镜像仓库实例名称。在 镜像仓库控制台 的 实例列表 页面，获取实例名称。
        :param pulumi.Input[builtins.str] update_time: 最近一次更新 OCI 制品仓库的时间。RFC3339 格式的 UTC+0 时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepositoryState.__new__(_RepositoryState)

        __props__.__dict__["access_level"] = access_level
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["registry"] = registry
        __props__.__dict__["update_time"] = update_time
        return Repository(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> pulumi.Output[builtins.str]:
        """
        访问等级，取值如下：Private：私有类型 OCI 制品仓库，只能被有权限的用户访问。Public：公有类型 OCI 制品仓库，可以被所有用户访问。单次可填写一个或多个访问等级。
        """
        return pulumi.get(self, "access_level")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        创建 OCI 制品仓库的时间。RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        镜像仓库描述，描述长度为 0~300 个 UTF-8 字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        OCI 制品仓库名称。同一个命名空间下，名称必须唯一。支持小写英文、数字、分隔符（分隔符可输入一个.或/、一个或多个-、一个或两个_，且分隔符不能出现在首位或末位，不能连续出现），长度限制为 1～128 个字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[builtins.str]:
        """
        目标命名空间名称。在 镜像仓库控制台 目标实例的 命名空间 页面，获取命名空间名称。
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def registry(self) -> pulumi.Output[builtins.str]:
        """
        指定命名空间所属的镜像仓库实例名称。在 镜像仓库控制台 的 实例列表 页面，获取实例名称。
        """
        return pulumi.get(self, "registry")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        最近一次更新 OCI 制品仓库的时间。RFC3339 格式的 UTC+0 时间。
        """
        return pulumi.get(self, "update_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceEndpoint',
    'InstanceTag',
    'GetInstanceEndpointResult',
    'GetInstanceTagResult',
]

@pulumi.output_type
class InstanceEndpoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "addressType":
            suggest = "address_type"
        elif key == "eipId":
            suggest = "eip_id"
        elif key == "endpointId":
            suggest = "endpoint_id"
        elif key == "endpointStr":
            suggest = "endpoint_str"
        elif key == "networkType":
            suggest = "network_type"
        elif key == "privateDnsVisibility":
            suggest = "private_dns_visibility"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceEndpoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceEndpoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceEndpoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 address_type: Optional[builtins.str] = None,
                 eip_id: Optional[builtins.str] = None,
                 endpoint_id: Optional[builtins.str] = None,
                 endpoint_str: Optional[builtins.str] = None,
                 network_type: Optional[builtins.str] = None,
                 private_dns_visibility: Optional[builtins.bool] = None):
        """
        :param builtins.str address_type: 连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        :param builtins.str eip_id: 当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        :param builtins.str endpoint_id: 连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        :param builtins.str endpoint_str: 连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        :param builtins.str network_type: 连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        :param builtins.bool private_dns_visibility: 私网域名是否开启公网解析。
        """
        if address_type is not None:
            pulumi.set(__self__, "address_type", address_type)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if endpoint_str is not None:
            pulumi.set(__self__, "endpoint_str", endpoint_str)
        if network_type is not None:
            pulumi.set(__self__, "network_type", network_type)
        if private_dns_visibility is not None:
            pulumi.set(__self__, "private_dns_visibility", private_dns_visibility)

    @property
    @pulumi.getter(name="addressType")
    def address_type(self) -> Optional[builtins.str]:
        """
        连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        """
        return pulumi.get(self, "address_type")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[builtins.str]:
        """
        当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[builtins.str]:
        """
        连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        """
        return pulumi.get(self, "endpoint_id")

    @property
    @pulumi.getter(name="endpointStr")
    def endpoint_str(self) -> Optional[builtins.str]:
        """
        连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        """
        return pulumi.get(self, "endpoint_str")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[builtins.str]:
        """
        连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="privateDnsVisibility")
    def private_dns_visibility(self) -> Optional[builtins.bool]:
        """
        私网域名是否开启公网解析。
        """
        return pulumi.get(self, "private_dns_visibility")


@pulumi.output_type
class InstanceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 实例所绑定标签的标签键。
        :param builtins.str value: 实例所绑定标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        实例所绑定标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        实例所绑定标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInstanceEndpointResult(dict):
    def __init__(__self__, *,
                 address_type: builtins.str,
                 eip_id: builtins.str,
                 endpoint_id: builtins.str,
                 endpoint_str: builtins.str,
                 network_type: builtins.str,
                 private_dns_visibility: builtins.bool):
        """
        :param builtins.str address_type: 连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        :param builtins.str eip_id: 当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        :param builtins.str endpoint_id: 连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        :param builtins.str endpoint_str: 连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        :param builtins.str network_type: 连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        :param builtins.bool private_dns_visibility: 私网域名是否开启公网解析。
        """
        pulumi.set(__self__, "address_type", address_type)
        pulumi.set(__self__, "eip_id", eip_id)
        pulumi.set(__self__, "endpoint_id", endpoint_id)
        pulumi.set(__self__, "endpoint_str", endpoint_str)
        pulumi.set(__self__, "network_type", network_type)
        pulumi.set(__self__, "private_dns_visibility", private_dns_visibility)

    @property
    @pulumi.getter(name="addressType")
    def address_type(self) -> builtins.str:
        """
        连接地址类型，关于连接地址的更多信息，请参见连接地址类型。取值范围如下：Zk：ZK 地址。Thrift：Thrift2 地址。HBaseReUsedEipId：当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示实例中其他组件（如 RS 节点、Master 节点等）共享绑定使用的 EIP ID 信息。
        """
        return pulumi.get(self, "address_type")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> builtins.str:
        """
        当 ZK 连接地址或 Thrift2 连接地址开启了公网访问时，会返回该参数，表示 EIP ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> builtins.str:
        """
        连接地址 ID。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的 ID。当连接地址类型为 HBaseReUsedEipId 时，连接地址 ID 也固定为 HBaseReUsedEipId。
        """
        return pulumi.get(self, "endpoint_id")

    @property
    @pulumi.getter(name="endpointStr")
    def endpoint_str(self) -> builtins.str:
        """
        连接地址的连接串。说明默认仅返回 ZK 私网连接地址。若您申请了 Thrift2 连接地址，或者为 ZK 或 Thrift2 连接地址开启了公网访问，那么还会同时对应连接地址的连接串。当连接地址类型为 HBaseReUsedEipId 时，连接地址的连接串也固定为 HBaseReUsedEipId。
        """
        return pulumi.get(self, "endpoint_str")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> builtins.str:
        """
        连接地址网络类型。取值范围如下：Public：公网访问地址。Private：私网访问地址。
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="privateDnsVisibility")
    def private_dns_visibility(self) -> builtins.bool:
        """
        私网域名是否开启公网解析。
        """
        return pulumi.get(self, "private_dns_visibility")


@pulumi.output_type
class GetInstanceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 实例所绑定标签的标签键。
        :param builtins.str value: 实例所绑定标签的标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        实例所绑定标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        实例所绑定标签的标签值。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .get_policies import *
from .get_policy import *
from .get_project import *
from .get_projects import *
from .get_role import *
from .get_roles import *
from .get_user import *
from .get_users import *
from .policy import *
from .project import *
from .role import *
from .user import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VpcArgs', 'Vpc']

@pulumi.input_type
class VpcArgs:
    def __init__(__self__, *,
                 cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dns_servers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 ipv4_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_cidr_blocks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 support_ipv4_gateway: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VpcTagArgs']]]] = None,
                 vpc_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Vpc resource.
        :param pulumi.Input[builtins.str] cidr_block: VPC的IPv4网段。您可以使用以下网段或其子集作为VPC的IPv4网段：192.168.0.0/16 ~ 24、10.0.0.0/8 ~ 24、172.16.0.0/12 ~ 24。
        :param pulumi.Input[builtins.str] description: VPC的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不能以http://或https://开头。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dns_servers: VPC的DNS服务器地址。单次调用数量上限为5个，每个DnsServer必须以合法IP形式给出。多个IP之间用&分隔。不填则配置为默认DNS服务器地址。
        :param pulumi.Input[builtins.str] ipv4_gateway_id: VPC 绑定的 IPv4 网关的 ID。
        :param pulumi.Input[builtins.str] ipv6_cidr_block: VPC的IPv6网段。传入此参数后，参数Ipv6MaskLen不生效。参数Ipv6Isp传入非BGP后，参数Ipv6MaskLen和参数Ipv6CidrBlock二者必须传入一个。参数Ipv6Isp未传或传入BGP，此参数未传，则由系统自动分配IPv6网段。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] nat_gateway_ids: VPC中创建的NAT网关的ID。
        :param pulumi.Input[builtins.str] project_name: VPC所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] secondary_cidr_blocks: VPC的辅助网段。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: VPC中子网的列表。
        :param pulumi.Input[builtins.bool] support_ipv4_gateway: VPC 是否启用 IPv4 网关。false（默认值）：不启用。true：启用。
        :param pulumi.Input[builtins.str] vpc_name: VPC的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为VPC实例的ID。不能以http://或https://开头。
        """
        if cidr_block is not None:
            pulumi.set(__self__, "cidr_block", cidr_block)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dns_servers is not None:
            pulumi.set(__self__, "dns_servers", dns_servers)
        if ipv4_gateway_id is not None:
            pulumi.set(__self__, "ipv4_gateway_id", ipv4_gateway_id)
        if ipv6_cidr_block is not None:
            pulumi.set(__self__, "ipv6_cidr_block", ipv6_cidr_block)
        if nat_gateway_ids is not None:
            pulumi.set(__self__, "nat_gateway_ids", nat_gateway_ids)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if secondary_cidr_blocks is not None:
            pulumi.set(__self__, "secondary_cidr_blocks", secondary_cidr_blocks)
        if subnet_ids is not None:
            pulumi.set(__self__, "subnet_ids", subnet_ids)
        if support_ipv4_gateway is not None:
            pulumi.set(__self__, "support_ipv4_gateway", support_ipv4_gateway)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_name is not None:
            pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的IPv4网段。您可以使用以下网段或其子集作为VPC的IPv4网段：192.168.0.0/16 ~ 24、10.0.0.0/8 ~ 24、172.16.0.0/12 ~ 24。
        """
        return pulumi.get(self, "cidr_block")

    @cidr_block.setter
    def cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cidr_block", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不能以http://或https://开头。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dnsServers")
    def dns_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC的DNS服务器地址。单次调用数量上限为5个，每个DnsServer必须以合法IP形式给出。多个IP之间用&分隔。不填则配置为默认DNS服务器地址。
        """
        return pulumi.get(self, "dns_servers")

    @dns_servers.setter
    def dns_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "dns_servers", value)

    @property
    @pulumi.getter(name="ipv4GatewayId")
    def ipv4_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC 绑定的 IPv4 网关的 ID。
        """
        return pulumi.get(self, "ipv4_gateway_id")

    @ipv4_gateway_id.setter
    def ipv4_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv4_gateway_id", value)

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的IPv6网段。传入此参数后，参数Ipv6MaskLen不生效。参数Ipv6Isp传入非BGP后，参数Ipv6MaskLen和参数Ipv6CidrBlock二者必须传入一个。参数Ipv6Isp未传或传入BGP，此参数未传，则由系统自动分配IPv6网段。
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_cidr_block", value)

    @property
    @pulumi.getter(name="natGatewayIds")
    def nat_gateway_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC中创建的NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_ids")

    @nat_gateway_ids.setter
    def nat_gateway_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "nat_gateway_ids", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="secondaryCidrBlocks")
    def secondary_cidr_blocks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC的辅助网段。
        """
        return pulumi.get(self, "secondary_cidr_blocks")

    @secondary_cidr_blocks.setter
    def secondary_cidr_blocks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "secondary_cidr_blocks", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC中子网的列表。
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter(name="supportIpv4Gateway")
    def support_ipv4_gateway(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        VPC 是否启用 IPv4 网关。false（默认值）：不启用。true：启用。
        """
        return pulumi.get(self, "support_ipv4_gateway")

    @support_ipv4_gateway.setter
    def support_ipv4_gateway(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "support_ipv4_gateway", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpcTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpcTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为VPC实例的ID。不能以http://或https://开头。
        """
        return pulumi.get(self, "vpc_name")

    @vpc_name.setter
    def vpc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_name", value)


@pulumi.input_type
class _VpcState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 associate_cens: Optional[pulumi.Input[Sequence[pulumi.Input['VpcAssociateCenArgs']]]] = None,
                 cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 creation_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dns_servers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 ipv4_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 is_default: Optional[pulumi.Input[builtins.bool]] = None,
                 nat_gateway_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 network_acl_num: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 secondary_cidr_blocks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 support_ipv4_gateway: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VpcTagArgs']]]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None,
                 user_cidr_blocks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Vpc resources.
        :param pulumi.Input[builtins.str] account_id: VPC所属账号的ID。
        :param pulumi.Input[builtins.str] cidr_block: VPC的IPv4网段。您可以使用以下网段或其子集作为VPC的IPv4网段：192.168.0.0/16 ~ 24、10.0.0.0/8 ~ 24、172.16.0.0/12 ~ 24。
        :param pulumi.Input[builtins.str] creation_time: 创建VPC的时间。
        :param pulumi.Input[builtins.str] description: VPC的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不能以http://或https://开头。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dns_servers: VPC的DNS服务器地址。单次调用数量上限为5个，每个DnsServer必须以合法IP形式给出。多个IP之间用&分隔。不填则配置为默认DNS服务器地址。
        :param pulumi.Input[builtins.str] ipv4_gateway_id: VPC 绑定的 IPv4 网关的 ID。
        :param pulumi.Input[builtins.str] ipv6_cidr_block: VPC的IPv6网段。传入此参数后，参数Ipv6MaskLen不生效。参数Ipv6Isp传入非BGP后，参数Ipv6MaskLen和参数Ipv6CidrBlock二者必须传入一个。参数Ipv6Isp未传或传入BGP，此参数未传，则由系统自动分配IPv6网段。
        :param pulumi.Input[builtins.bool] is_default: 该VPC是否为默认VPC。true：默认VPC，表示该VPC是创建ECS实例时系统自动创建的VPC。false：非默认VPC，表示该VPC是用户手动创建的。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] nat_gateway_ids: VPC中创建的NAT网关的ID。
        :param pulumi.Input[builtins.str] network_acl_num: VPC中的网络ACL的数量。
        :param pulumi.Input[builtins.str] project_name: VPC所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] route_table_ids: VPC关联的路由表ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] secondary_cidr_blocks: VPC的辅助网段。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: VPC中安全组的列表。
        :param pulumi.Input[builtins.str] status: VPC的状态。Creating：创建中。Pending：已创建。Available：可用。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: VPC中子网的列表。
        :param pulumi.Input[builtins.bool] support_ipv4_gateway: VPC 是否启用 IPv4 网关。false（默认值）：不启用。true：启用。
        :param pulumi.Input[builtins.str] update_time: 更新VPC的时间。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_cidr_blocks: VPC的用户网段。
        :param pulumi.Input[builtins.str] vpc_id: VPC的ID。
        :param pulumi.Input[builtins.str] vpc_name: VPC的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为VPC实例的ID。不能以http://或https://开头。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if associate_cens is not None:
            pulumi.set(__self__, "associate_cens", associate_cens)
        if cidr_block is not None:
            pulumi.set(__self__, "cidr_block", cidr_block)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dns_servers is not None:
            pulumi.set(__self__, "dns_servers", dns_servers)
        if ipv4_gateway_id is not None:
            pulumi.set(__self__, "ipv4_gateway_id", ipv4_gateway_id)
        if ipv6_cidr_block is not None:
            pulumi.set(__self__, "ipv6_cidr_block", ipv6_cidr_block)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if nat_gateway_ids is not None:
            pulumi.set(__self__, "nat_gateway_ids", nat_gateway_ids)
        if network_acl_num is not None:
            pulumi.set(__self__, "network_acl_num", network_acl_num)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if route_table_ids is not None:
            pulumi.set(__self__, "route_table_ids", route_table_ids)
        if secondary_cidr_blocks is not None:
            pulumi.set(__self__, "secondary_cidr_blocks", secondary_cidr_blocks)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_ids is not None:
            pulumi.set(__self__, "subnet_ids", subnet_ids)
        if support_ipv4_gateway is not None:
            pulumi.set(__self__, "support_ipv4_gateway", support_ipv4_gateway)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if user_cidr_blocks is not None:
            pulumi.set(__self__, "user_cidr_blocks", user_cidr_blocks)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name is not None:
            pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC所属账号的ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="associateCens")
    def associate_cens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpcAssociateCenArgs']]]]:
        return pulumi.get(self, "associate_cens")

    @associate_cens.setter
    def associate_cens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpcAssociateCenArgs']]]]):
        pulumi.set(self, "associate_cens", value)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的IPv4网段。您可以使用以下网段或其子集作为VPC的IPv4网段：192.168.0.0/16 ~ 24、10.0.0.0/8 ~ 24、172.16.0.0/12 ~ 24。
        """
        return pulumi.get(self, "cidr_block")

    @cidr_block.setter
    def cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cidr_block", value)

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建VPC的时间。
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不能以http://或https://开头。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dnsServers")
    def dns_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC的DNS服务器地址。单次调用数量上限为5个，每个DnsServer必须以合法IP形式给出。多个IP之间用&分隔。不填则配置为默认DNS服务器地址。
        """
        return pulumi.get(self, "dns_servers")

    @dns_servers.setter
    def dns_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "dns_servers", value)

    @property
    @pulumi.getter(name="ipv4GatewayId")
    def ipv4_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC 绑定的 IPv4 网关的 ID。
        """
        return pulumi.get(self, "ipv4_gateway_id")

    @ipv4_gateway_id.setter
    def ipv4_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv4_gateway_id", value)

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的IPv6网段。传入此参数后，参数Ipv6MaskLen不生效。参数Ipv6Isp传入非BGP后，参数Ipv6MaskLen和参数Ipv6CidrBlock二者必须传入一个。参数Ipv6Isp未传或传入BGP，此参数未传，则由系统自动分配IPv6网段。
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_cidr_block", value)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        该VPC是否为默认VPC。true：默认VPC，表示该VPC是创建ECS实例时系统自动创建的VPC。false：非默认VPC，表示该VPC是用户手动创建的。
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter(name="natGatewayIds")
    def nat_gateway_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC中创建的NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_ids")

    @nat_gateway_ids.setter
    def nat_gateway_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "nat_gateway_ids", value)

    @property
    @pulumi.getter(name="networkAclNum")
    def network_acl_num(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC中的网络ACL的数量。
        """
        return pulumi.get(self, "network_acl_num")

    @network_acl_num.setter
    def network_acl_num(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_acl_num", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="routeTableIds")
    def route_table_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC关联的路由表ID。
        """
        return pulumi.get(self, "route_table_ids")

    @route_table_ids.setter
    def route_table_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "route_table_ids", value)

    @property
    @pulumi.getter(name="secondaryCidrBlocks")
    def secondary_cidr_blocks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC的辅助网段。
        """
        return pulumi.get(self, "secondary_cidr_blocks")

    @secondary_cidr_blocks.setter
    def secondary_cidr_blocks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "secondary_cidr_blocks", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC中安全组的列表。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的状态。Creating：创建中。Pending：已创建。Available：可用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC中子网的列表。
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter(name="supportIpv4Gateway")
    def support_ipv4_gateway(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        VPC 是否启用 IPv4 网关。false（默认值）：不启用。true：启用。
        """
        return pulumi.get(self, "support_ipv4_gateway")

    @support_ipv4_gateway.setter
    def support_ipv4_gateway(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "support_ipv4_gateway", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpcTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpcTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新VPC的时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)

    @property
    @pulumi.getter(name="userCidrBlocks")
    def user_cidr_blocks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        VPC的用户网段。
        """
        return pulumi.get(self, "user_cidr_blocks")

    @user_cidr_blocks.setter
    def user_cidr_blocks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "user_cidr_blocks", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为VPC实例的ID。不能以http://或https://开头。
        """
        return pulumi.get(self, "vpc_name")

    @vpc_name.setter
    def vpc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_name", value)


@pulumi.type_token("bytepluscc:vpc/vpc:Vpc")
class Vpc(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dns_servers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 ipv4_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_cidr_blocks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 support_ipv4_gateway: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpcTagArgs', 'VpcTagArgsDict']]]]] = None,
                 vpc_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        私有网络为云上资源构建隔离的、自主配置的虚拟网络环境。可以在私有网络中自定义IP地址段、安全组、路由策略等网络特性，简单高效安全地管理云上资源。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/vpc:Vpc example "vpc_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cidr_block: VPC的IPv4网段。您可以使用以下网段或其子集作为VPC的IPv4网段：192.168.0.0/16 ~ 24、10.0.0.0/8 ~ 24、172.16.0.0/12 ~ 24。
        :param pulumi.Input[builtins.str] description: VPC的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不能以http://或https://开头。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dns_servers: VPC的DNS服务器地址。单次调用数量上限为5个，每个DnsServer必须以合法IP形式给出。多个IP之间用&分隔。不填则配置为默认DNS服务器地址。
        :param pulumi.Input[builtins.str] ipv4_gateway_id: VPC 绑定的 IPv4 网关的 ID。
        :param pulumi.Input[builtins.str] ipv6_cidr_block: VPC的IPv6网段。传入此参数后，参数Ipv6MaskLen不生效。参数Ipv6Isp传入非BGP后，参数Ipv6MaskLen和参数Ipv6CidrBlock二者必须传入一个。参数Ipv6Isp未传或传入BGP，此参数未传，则由系统自动分配IPv6网段。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] nat_gateway_ids: VPC中创建的NAT网关的ID。
        :param pulumi.Input[builtins.str] project_name: VPC所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] secondary_cidr_blocks: VPC的辅助网段。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: VPC中子网的列表。
        :param pulumi.Input[builtins.bool] support_ipv4_gateway: VPC 是否启用 IPv4 网关。false（默认值）：不启用。true：启用。
        :param pulumi.Input[builtins.str] vpc_name: VPC的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为VPC实例的ID。不能以http://或https://开头。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[VpcArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        私有网络为云上资源构建隔离的、自主配置的虚拟网络环境。可以在私有网络中自定义IP地址段、安全组、路由策略等网络特性，简单高效安全地管理云上资源。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/vpc:Vpc example "vpc_id"
        ```

        :param str resource_name: The name of the resource.
        :param VpcArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpcArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dns_servers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 ipv4_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_cidr_blocks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 support_ipv4_gateway: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpcTagArgs', 'VpcTagArgsDict']]]]] = None,
                 vpc_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpcArgs.__new__(VpcArgs)

            __props__.__dict__["cidr_block"] = cidr_block
            __props__.__dict__["description"] = description
            __props__.__dict__["dns_servers"] = dns_servers
            __props__.__dict__["ipv4_gateway_id"] = ipv4_gateway_id
            __props__.__dict__["ipv6_cidr_block"] = ipv6_cidr_block
            __props__.__dict__["nat_gateway_ids"] = nat_gateway_ids
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["secondary_cidr_blocks"] = secondary_cidr_blocks
            __props__.__dict__["subnet_ids"] = subnet_ids
            __props__.__dict__["support_ipv4_gateway"] = support_ipv4_gateway
            __props__.__dict__["tags"] = tags
            __props__.__dict__["vpc_name"] = vpc_name
            __props__.__dict__["account_id"] = None
            __props__.__dict__["associate_cens"] = None
            __props__.__dict__["creation_time"] = None
            __props__.__dict__["is_default"] = None
            __props__.__dict__["network_acl_num"] = None
            __props__.__dict__["route_table_ids"] = None
            __props__.__dict__["security_group_ids"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["update_time"] = None
            __props__.__dict__["user_cidr_blocks"] = None
            __props__.__dict__["vpc_id"] = None
        super(Vpc, __self__).__init__(
            'bytepluscc:vpc/vpc:Vpc',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            associate_cens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpcAssociateCenArgs', 'VpcAssociateCenArgsDict']]]]] = None,
            cidr_block: Optional[pulumi.Input[builtins.str]] = None,
            creation_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            dns_servers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            ipv4_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            ipv6_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
            is_default: Optional[pulumi.Input[builtins.bool]] = None,
            nat_gateway_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            network_acl_num: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            route_table_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            secondary_cidr_blocks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            support_ipv4_gateway: Optional[pulumi.Input[builtins.bool]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpcTagArgs', 'VpcTagArgsDict']]]]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None,
            user_cidr_blocks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vpc_name: Optional[pulumi.Input[builtins.str]] = None) -> 'Vpc':
        """
        Get an existing Vpc resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: VPC所属账号的ID。
        :param pulumi.Input[builtins.str] cidr_block: VPC的IPv4网段。您可以使用以下网段或其子集作为VPC的IPv4网段：192.168.0.0/16 ~ 24、10.0.0.0/8 ~ 24、172.16.0.0/12 ~ 24。
        :param pulumi.Input[builtins.str] creation_time: 创建VPC的时间。
        :param pulumi.Input[builtins.str] description: VPC的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不能以http://或https://开头。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] dns_servers: VPC的DNS服务器地址。单次调用数量上限为5个，每个DnsServer必须以合法IP形式给出。多个IP之间用&分隔。不填则配置为默认DNS服务器地址。
        :param pulumi.Input[builtins.str] ipv4_gateway_id: VPC 绑定的 IPv4 网关的 ID。
        :param pulumi.Input[builtins.str] ipv6_cidr_block: VPC的IPv6网段。传入此参数后，参数Ipv6MaskLen不生效。参数Ipv6Isp传入非BGP后，参数Ipv6MaskLen和参数Ipv6CidrBlock二者必须传入一个。参数Ipv6Isp未传或传入BGP，此参数未传，则由系统自动分配IPv6网段。
        :param pulumi.Input[builtins.bool] is_default: 该VPC是否为默认VPC。true：默认VPC，表示该VPC是创建ECS实例时系统自动创建的VPC。false：非默认VPC，表示该VPC是用户手动创建的。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] nat_gateway_ids: VPC中创建的NAT网关的ID。
        :param pulumi.Input[builtins.str] network_acl_num: VPC中的网络ACL的数量。
        :param pulumi.Input[builtins.str] project_name: VPC所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] route_table_ids: VPC关联的路由表ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] secondary_cidr_blocks: VPC的辅助网段。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: VPC中安全组的列表。
        :param pulumi.Input[builtins.str] status: VPC的状态。Creating：创建中。Pending：已创建。Available：可用。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: VPC中子网的列表。
        :param pulumi.Input[builtins.bool] support_ipv4_gateway: VPC 是否启用 IPv4 网关。false（默认值）：不启用。true：启用。
        :param pulumi.Input[builtins.str] update_time: 更新VPC的时间。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_cidr_blocks: VPC的用户网段。
        :param pulumi.Input[builtins.str] vpc_id: VPC的ID。
        :param pulumi.Input[builtins.str] vpc_name: VPC的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为VPC实例的ID。不能以http://或https://开头。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpcState.__new__(_VpcState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["associate_cens"] = associate_cens
        __props__.__dict__["cidr_block"] = cidr_block
        __props__.__dict__["creation_time"] = creation_time
        __props__.__dict__["description"] = description
        __props__.__dict__["dns_servers"] = dns_servers
        __props__.__dict__["ipv4_gateway_id"] = ipv4_gateway_id
        __props__.__dict__["ipv6_cidr_block"] = ipv6_cidr_block
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["nat_gateway_ids"] = nat_gateway_ids
        __props__.__dict__["network_acl_num"] = network_acl_num
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["route_table_ids"] = route_table_ids
        __props__.__dict__["secondary_cidr_blocks"] = secondary_cidr_blocks
        __props__.__dict__["security_group_ids"] = security_group_ids
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_ids"] = subnet_ids
        __props__.__dict__["support_ipv4_gateway"] = support_ipv4_gateway
        __props__.__dict__["tags"] = tags
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["user_cidr_blocks"] = user_cidr_blocks
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpc_name"] = vpc_name
        return Vpc(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        VPC所属账号的ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="associateCens")
    def associate_cens(self) -> pulumi.Output[Sequence['outputs.VpcAssociateCen']]:
        return pulumi.get(self, "associate_cens")

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> pulumi.Output[builtins.str]:
        """
        VPC的IPv4网段。您可以使用以下网段或其子集作为VPC的IPv4网段：192.168.0.0/16 ~ 24、10.0.0.0/8 ~ 24、172.16.0.0/12 ~ 24。
        """
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> pulumi.Output[builtins.str]:
        """
        创建VPC的时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        VPC的描述信息。长度限制为0~ 255个字符。不填默认为空字符串。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。不能以http://或https://开头。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dnsServers")
    def dns_servers(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        VPC的DNS服务器地址。单次调用数量上限为5个，每个DnsServer必须以合法IP形式给出。多个IP之间用&分隔。不填则配置为默认DNS服务器地址。
        """
        return pulumi.get(self, "dns_servers")

    @property
    @pulumi.getter(name="ipv4GatewayId")
    def ipv4_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        VPC 绑定的 IPv4 网关的 ID。
        """
        return pulumi.get(self, "ipv4_gateway_id")

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> pulumi.Output[builtins.str]:
        """
        VPC的IPv6网段。传入此参数后，参数Ipv6MaskLen不生效。参数Ipv6Isp传入非BGP后，参数Ipv6MaskLen和参数Ipv6CidrBlock二者必须传入一个。参数Ipv6Isp未传或传入BGP，此参数未传，则由系统自动分配IPv6网段。
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[builtins.bool]:
        """
        该VPC是否为默认VPC。true：默认VPC，表示该VPC是创建ECS实例时系统自动创建的VPC。false：非默认VPC，表示该VPC是用户手动创建的。
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="natGatewayIds")
    def nat_gateway_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        VPC中创建的NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_ids")

    @property
    @pulumi.getter(name="networkAclNum")
    def network_acl_num(self) -> pulumi.Output[builtins.str]:
        """
        VPC中的网络ACL的数量。
        """
        return pulumi.get(self, "network_acl_num")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        VPC所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="routeTableIds")
    def route_table_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        VPC关联的路由表ID。
        """
        return pulumi.get(self, "route_table_ids")

    @property
    @pulumi.getter(name="secondaryCidrBlocks")
    def secondary_cidr_blocks(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        VPC的辅助网段。
        """
        return pulumi.get(self, "secondary_cidr_blocks")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        VPC中安全组的列表。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        VPC的状态。Creating：创建中。Pending：已创建。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        VPC中子网的列表。
        """
        return pulumi.get(self, "subnet_ids")

    @property
    @pulumi.getter(name="supportIpv4Gateway")
    def support_ipv4_gateway(self) -> pulumi.Output[builtins.bool]:
        """
        VPC 是否启用 IPv4 网关。false（默认值）：不启用。true：启用。
        """
        return pulumi.get(self, "support_ipv4_gateway")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.VpcTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        更新VPC的时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="userCidrBlocks")
    def user_cidr_blocks(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        VPC的用户网段。
        """
        return pulumi.get(self, "user_cidr_blocks")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> pulumi.Output[builtins.str]:
        """
        VPC的名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。不填默认为VPC实例的ID。不能以http://或https://开头。
        """
        return pulumi.get(self, "vpc_name")

